class Calculator:
    @staticmethod
    def calculate_square_area(side):
        return side **2

    @staticmethod
    def calculate_triangle_area(base, height):
        return 0.5*base*height

    @staticmethod
    def calculate_trapezoid_area(base1,base2, height):
        return 0.5 * (base1+base2) * height

    @staticmethod
    def compare_squares(side1, side2):
        return side1**2 == side2**2



from setuptools import setup, find_packages


def read_file(file_name):
    with open(file_name, 'r', encoding='utf-8') as file:
        return file.read()


setup(
    name="UdemyCalculator",
    version="1.0.1",
    packages=find_packages(include=['udemyCalculator', 'udemyCalculator.*']),
    url="",
    author="Idan Chen",
    description="This is my udemy calculator package",
    long_description=read_file(file_name="README.md"),
    python_requires=">=3.6"
)
